@@ -1,14 +1,15 @@
 /*
  * $Source: /usr/local/cvsroot/erserver/erserver/java/src/com/postgres/util/jdbc/ConnectionPool.java,v $
- * $Author: asullivan $ $Revision: 1.1.1.1 $ $Date: 2003/08/26 19:02:34 $
+ * $Author: ronz $ $Revision: 1.2 $ $Date: 2004/03/09 17:14:52 $
  *
  */
 
 package com.postgres.util.jdbc;
 
-import com.postgres.util.timer.*;
 import com.postgres.util.Logger.Logger;
-import java.sql.*;
+import com.postgres.util.timer.Timer;
+import com.postgres.util.timer.TimerListener;
+import com.postgres.replic.server.props.ConnectionPoolProps;
 
 /**
  * <p>This class serves as a JDBC connection repository. Since
@@ -33,14 +34,14 @@ public class ConnectionPool
 implements TimerListener {
 
 
-    public static final String JDBC_DRIVER = "JDBCDriver";
+   /* public static final String JDBC_DRIVER = "JDBCDriver";
     public static final String JDBC_USER = "user";
     public static final String JDBC_PASS = "password";
     public static final String JDBC_URL = "JDBCConnectionURL";
     public static final String SIZE = "ConnectionPoolMax";
     public static final String SIZE_MAX = "JDBCDriver";
     public static final String CONN_TIMEOUT = "ConnectionTimeout";
-    public static final String CONN_USE_COUNT = "ConnectionUseCount";
+    public static final String CONN_USE_COUNT = "ConnectionUseCount";*/
 
     private boolean debug = false;
     private Logger logger;
@@ -134,8 +135,7 @@ implements TimerListener {
     /**
      * <p>Initializes the ConnectionPool object with the specified
      * configuration file
-     * @param config Configuration file name
-     * @return true if the ConnectionPool was initialized properly
+     * @param props Configuration file name
      */
     public void initialize(java.util.Properties props) throws Exception {
         // Load the configuration parameters. Any leftover parameters
@@ -165,7 +165,8 @@ implements TimerListener {
             // Stop our timer thread
             if (m_timer != null) {
                 try {
-                     m_timer.stop();
+                     //m_timer.stop();
+					m_timer.interrupt();
                 } catch (Exception e) {}
 
                 m_timer = null;
@@ -263,7 +264,7 @@ implements TimerListener {
     /**
      * <p>Places the connection back into the connection pool,
      * or closes the connection if the maximum use count has been reached
-     * @param Connection object to close
+     * @param con object to close
      */
     public synchronized void close(java.sql.Connection con) {
         // Find the connection in the pool
@@ -326,7 +327,7 @@ implements TimerListener {
 
     /**
      * <p>Closes the connection in the given ConnectionObject
-     * @param connectObject ConnectionObject
+     * @param connectionObject ConnectionObject
      */
     private void close(ConnectionObject connectionObject) {
         if (connectionObject != null) {
@@ -415,11 +416,10 @@ implements TimerListener {
      * properties will be returned. Returns null if the
      * properties could not be loaded
      * @param props Configuration Properties
-     * @return true if the configuration file was loaded
      */
     private void loadConfig(java.util.Properties props)
     throws Exception {
-        boolean rc = false;
+        //boolean rc = false;
 
         try {
             m_JDBCProperties = props;
@@ -427,7 +427,7 @@ implements TimerListener {
             // Got the properties. Pull out the properties that we
             // are interested in
             setProperties();
-            rc = true;
+            //rc = true;
         } catch (Exception e) {
             throw new Exception("ConnectionPool::loadConfig: " + e.toString());
         }
@@ -436,35 +436,40 @@ implements TimerListener {
     private void setProperties() {
         // Got the properties. Pull out the properties that we
         // are interested in
-        m_JDBCDriver = consume(m_JDBCProperties, "JDBCDriver");
+        m_JDBCDriver = consume(m_JDBCProperties, ConnectionPoolProps.JDBC_DRIVER);
         //trace("JDBCDriver:"+m_JDBCDriver);
-        m_JDBC_user = consume(m_JDBCProperties, "user");
+        m_JDBC_user = consume(m_JDBCProperties, ConnectionPoolProps.JDBC_USER);
         //trace("user:"+m_JDBC_user);
-        m_JDBC_pass = consume(m_JDBCProperties, "password");
+        m_JDBC_pass = consume(m_JDBCProperties, ConnectionPoolProps.JDBC_PASS);
         m_JDBCConnectionURL = consume(m_JDBCProperties,
-        "JDBCConnectionURL");
+                ConnectionPoolProps.JDBC_URL);
+				//"JDBCConnectionURL");
         m_ConnectionPoolSize = consumeInt(m_JDBCProperties,
-        "ConnectionPoolSize");
+                ConnectionPoolProps.SIZE);
+				//"ConnectionPoolSize");
         m_ConnectionPoolSize = Math.max(DEF_SIZE, m_ConnectionPoolSize);
 
         m_ConnectionPoolMax = consumeInt(m_JDBCProperties,
-        "ConnectionPoolMax");
+				ConnectionPoolProps.SIZE_MAX);
+//        "ConnectionPoolMax");
         m_ConnectionPoolMax = Math.max(DEF_SIZE_MAX, m_ConnectionPoolMax);
 
         m_ConnectionTimeout = consumeInt(m_JDBCProperties,
-        "ConnectionTimeout");
+                ConnectionPoolProps.CONN_TIMEOUT);
+				//"ConnectionTimeout");
         m_ConnectionTimeout = m_ConnectionTimeout < 0 ? DEF_CONN_TIMEOUT :
             m_ConnectionTimeout;
 
         m_ConnectionUseCount = consumeInt(m_JDBCProperties,
-        "ConnectionUseCount");
+				ConnectionPoolProps.CONN_USE_COUNT);
+        //"ConnectionUseCount");
         m_ConnectionUseCount = m_ConnectionUseCount < 0 ? DEF_CONN_USE_COUNT :
             m_ConnectionUseCount;
     }
 
     /**
      * <p>Consumes the given property and returns the value.
-     * @param properties Properties table
+     * @param p Properties table
      * @param key Key of the property to retrieve and remove from
      * the properties table
      * @return Value of the property, or null if not found
@@ -488,7 +493,7 @@ implements TimerListener {
 
     /**
      * <p>Consumes the given property and returns the integer value.
-     * @param properties Properties table
+     * @param p Properties table
      * @param key Key of the property to retrieve and remove from
      * the properties table
      * @return Value of the property, or -1 if not found
@@ -513,7 +518,6 @@ implements TimerListener {
     /**
      * <p>Creates the initial connection pool. A timer thread
      * is also created so that connection timeouts can be handled.
-     * @return true if the pool was created
      */
     private void createPool() throws Exception {
         // Sanity check our properties
@@ -575,7 +579,7 @@ implements TimerListener {
         // themselves with the JDBC DriverManager when they
         // are instantiated
         if (debug) trace("Registering " + m_JDBCDriver);
-        java.sql.Driver d = (java.sql.Driver)
+        //java.sql.Driver d = (java.sql.Driver)
         Class.forName(m_JDBCDriver).newInstance();
 
         // Create the vector for the pool
